%define anolis_release 4

Summary: A library for password generation and password quality checking
Name: libpwquality
Version: 1.4.4
Release: %{anolis_release}%{?dist}
# The package is BSD licensed with option to relicense as GPLv2+
# - this option is redundant as the BSD license allows that anyway.
License: BSD or GPLv2+
Source0: https://github.com/libpwquality/libpwquality/releases/download/libpwquality-%{version}/libpwquality-%{version}.tar.bz2

%global _pwqlibdir %{_libdir}
%global _moduledir %{_libdir}/security
%global _secconfdir %{_sysconfdir}/security

Recommends: cracklib-dicts >= 2.8
Requires: pam
BuildRequires: gcc
BuildRequires: cracklib-devel
BuildRequires: gettext
BuildRequires: pam-devel
BuildRequires: python3-devel

URL: https://github.com/libpwquality/libpwquality/

# we don't want to provide private python extension libs
%define __provides_exclude_from ^(%{python3_sitearch})/.*\.so$.

%description
This is a library for password quality checks and generation
of random passwords that pass the checks.
This library uses the cracklib and cracklib dictionaries
to perform some of the checks.

%package doc
Summary:        Documentation files for %{name}
Requires:       %{name} = %{version}-%{release}
BuildArch:      noarch

%description    doc
The %{name}-doc package contains documentation files for %{name}.

%package devel
Summary: Support for development of applications using the libpwquality library
Requires: libpwquality = %{version}-%{release}
Requires: pkgconfig

%description devel
Files needed for development of applications using the libpwquality
library.
See the pwquality.h header file for the API.

%package -n python3-pwquality
Summary: Python bindings for the libpwquality library
Requires: libpwquality = %{version}-%{release}

%description -n python3-pwquality
This is pwquality Python module that provides Python bindings
for the libpwquality library. These bindings can be used
for easy password quality checking and generation of random
pronounceable passwords from Python applications.

%prep
%setup -q

%build
# https://github.com/pypa/setuptools/issues/3143
export SETUPTOOLS_USE_DISTUTILS=stdlib
%configure \
	--with-securedir=%{_moduledir} \
	--with-pythonsitedir=%{python3_sitearch} \
	--with-python-binary=%{__python3} \
	--disable-static

%make_build

%install
%make_install


%if "%{_pwqlibdir}" != "%{_libdir}"
pushd $RPM_BUILD_ROOT%{_libdir}
mv libpwquality.so.* $RPM_BUILD_ROOT%{_pwqlibdir}
ln -sf %{_pwqlibdir}/libpwquality.so.*.* libpwquality.so
popd
%endif
rm -f $RPM_BUILD_ROOT%{_libdir}/*.la
rm -f $RPM_BUILD_ROOT%{_moduledir}/*.la

mkdir $RPM_BUILD_ROOT%{_secconfdir}/pwquality.conf.d

%find_lang libpwquality

%generate_compatibility_deps

%check
# Nothing yet

%ldconfig_scriptlets

%files -f libpwquality.lang
%dir %{abidir}
%{!?_licensedir:%global license %%doc}
%license COPYING
%{_bindir}/pwmake
%{_bindir}/pwscore
%{_moduledir}/pam_pwquality.so
%{_pwqlibdir}/libpwquality.so.*
%config(noreplace) %{_secconfdir}/pwquality.conf
%{_secconfdir}/pwquality.conf.d
%{_mandir}/man1/*
%{_mandir}/man5/*
%{_mandir}/man8/*
%{abidir}/libpwquality.dump
%{abidir}/pam_pwquality.dump
%{abidir}/pwquality.cpython-310-%{_arch}-linux-gnu.dump

%files doc
%doc README NEWS AUTHORS

%files devel
%{_includedir}/pwquality.h
%{_libdir}/libpwquality.so
%{_libdir}/pkgconfig/*.pc
%{_mandir}/man3/*


%files -n python3-pwquality
%{python3_sitearch}/*.so
%{python3_sitearch}/*.egg-info

%changelog
* Wed Nov 02 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.4.4-4
- optimise spec file

* Sat Oct 08 2022 mgb01105731 <mgb01105731@alibaba-inc.com> - 1.4.4-3
- add doc package

* Fri Jun 10 2022 Chunmei Xu <xuchunmei@linux.alibaba.com> - 1.4.4-2
- Don't BuildRequires python-setuptools, use Python-bundled distutils
- fix build failed with python-setuptools-60*

* Wed Mar 09 2022 Hongwei Qin <qhw01063182@alibaba-inc.com> - 1.4.4-1
- Translation updates
- Init for Anolis OS 23
